Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/ValveSoftware/openvr.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJoe Ludwig <joe@valvesoftware.com>2019-09-17 04:08:17 +0300
committerJoe Ludwig <joe@valvesoftware.com>2019-09-17 04:08:17 +0300
commit5aa6c5f0f6520c59c4dce124541ecc62604fd7a5 (patch)
tree19a93588b03120805b3e7d1fe76e0aa0ccd627bc
parent52065df3d6f3af96300dac98cdf7397f26abfcd7 (diff)
**OpenVR SDK 1.7.15**v1.7.15
Events: * VREvent_Compositor_MirrorWindowShown and VREvent_Compositor_MirrorWindowHidden are no longer supported and have been removed. IVRApplications: * Added `VRApplicationProperty_IsHidden_Bool`, which is true for applications which the user has chosen to hide in their Steam library. IVRCompositor: * Disabled the following functions: `ShowMirrorWindow()`, `HideMirrorWindow()`, and `IsMirrorWindowVisible()`. These are no longer support with the new VR View window. IVROverlay: * Removed support for so-called "high quality" overlays, along with the functions that create them. These overlays never supported laser mouse interaction, were unable to act as dashboard overlays, and generally didn't play well with the rest of SteamVR. This approach to rendering overlays also didn't scale to modern displays. Any existing apps that still use the APIs in old versions of the SDK will fall back to being rendered as standard overlays. IVRTrackedCamera: * Added support for setting which tracking universe poses are returned in. Set the camera tracking universe with `SetCameraTrackingSpace(...)` and retrieve the current tracking universe with `GetCameraTrackingSpace(...)`. The camera tracking universe defaults to standing. Driver Interface: * Added support for overriding HMD properties from display redirect drivers. Any properties written to the ` k_ulDisplayRedirectContainer` property container will be read instead of the properties on the HMD itself. This container is only valid after Activate has been called on a display redirect device. * Created an optional Prop_NamedIconPathDeviceStandbyAlert_String that drivers can use to declare a device icon for a combination of standby + alert states. It's recommended to visually be a combination of the Prop_NamedIconPathDeviceReadyAlert_String and Prop_NamedIconPathDeviceStandby_String icons. [git-p4: depot-paths = "//vr/steamvr/sdk_release/": change = 5356236]
-rwxr-xr-xbin/linux32/libopenvr_api.sobin304950 -> 305108 bytes
-rwxr-xr-xbin/linux32/libopenvr_api.so.dbgbin2143067 -> 2144517 bytes
-rwxr-xr-xbin/linux64/libopenvr_api.sobin307641 -> 307835 bytes
-rwxr-xr-xbin/linux64/libopenvr_api.so.dbgbin2690382 -> 2692464 bytes
-rwxr-xr-xbin/osx32/libopenvr_api.dylibbin155684 -> 155684 bytes
-rw-r--r--bin/osx32/libopenvr_api.dylib.dSYM/Contents/Resources/DWARF/libopenvr_api.dylibbin1187823 -> 1188012 bytes
-rw-r--r--bin/win32/openvr_api.dllbin490784 -> 490784 bytes
-rw-r--r--bin/win32/openvr_api.pdbbin9900032 -> 9900032 bytes
-rw-r--r--bin/win64/openvr_api.dllbin598816 -> 598816 bytes
-rw-r--r--bin/win64/openvr_api.pdbbin9744384 -> 9744384 bytes
-rw-r--r--headers/openvr.h57
-rw-r--r--headers/openvr_api.cs65
-rw-r--r--headers/openvr_api.json59
-rw-r--r--headers/openvr_capi.h30
-rw-r--r--headers/openvr_driver.h34
-rwxr-xr-xlib/linux32/libopenvr_api.sobin2143067 -> 2144517 bytes
-rwxr-xr-xlib/linux64/libopenvr_api.sobin2690382 -> 2692464 bytes
-rw-r--r--samples/bin/linux32/libopenvr_api.sobin304950 -> 305108 bytes
-rw-r--r--samples/bin/linux64/libopenvr_api.sobin307641 -> 307835 bytes
-rw-r--r--samples/bin/osx32/libopenvr_api.dylibbin155684 -> 155684 bytes
-rw-r--r--samples/bin/win32/openvr_api.dllbin490784 -> 490784 bytes
-rw-r--r--samples/bin/win64/openvr_api.dllbin598816 -> 598816 bytes
-rw-r--r--samples/driver_sample/driver_sample.cpp2
23 files changed, 154 insertions, 93 deletions
diff --git a/bin/linux32/libopenvr_api.so b/bin/linux32/libopenvr_api.so
index c95dc19..db91225 100755
--- a/bin/linux32/libopenvr_api.so
+++ b/bin/linux32/libopenvr_api.so
Binary files differ
diff --git a/bin/linux32/libopenvr_api.so.dbg b/bin/linux32/libopenvr_api.so.dbg
index 96f0d97..cbe6046 100755
--- a/bin/linux32/libopenvr_api.so.dbg
+++ b/bin/linux32/libopenvr_api.so.dbg
Binary files differ
diff --git a/bin/linux64/libopenvr_api.so b/bin/linux64/libopenvr_api.so
index 2575362..3af38ac 100755
--- a/bin/linux64/libopenvr_api.so
+++ b/bin/linux64/libopenvr_api.so
Binary files differ
diff --git a/bin/linux64/libopenvr_api.so.dbg b/bin/linux64/libopenvr_api.so.dbg
index 2502ff0..53c2a86 100755
--- a/bin/linux64/libopenvr_api.so.dbg
+++ b/bin/linux64/libopenvr_api.so.dbg
Binary files differ
diff --git a/bin/osx32/libopenvr_api.dylib b/bin/osx32/libopenvr_api.dylib
index 059ac11..fae6aca 100755
--- a/bin/osx32/libopenvr_api.dylib
+++ b/bin/osx32/libopenvr_api.dylib
Binary files differ
diff --git a/bin/osx32/libopenvr_api.dylib.dSYM/Contents/Resources/DWARF/libopenvr_api.dylib b/bin/osx32/libopenvr_api.dylib.dSYM/Contents/Resources/DWARF/libopenvr_api.dylib
index 8c9a1d6..e3f1a4b 100644
--- a/bin/osx32/libopenvr_api.dylib.dSYM/Contents/Resources/DWARF/libopenvr_api.dylib
+++ b/bin/osx32/libopenvr_api.dylib.dSYM/Contents/Resources/DWARF/libopenvr_api.dylib
Binary files differ
diff --git a/bin/win32/openvr_api.dll b/bin/win32/openvr_api.dll
index 4b06e42..a9167aa 100644
--- a/bin/win32/openvr_api.dll
+++ b/bin/win32/openvr_api.dll
Binary files differ
diff --git a/bin/win32/openvr_api.pdb b/bin/win32/openvr_api.pdb
index 81e9f1f..8d3aef1 100644
--- a/bin/win32/openvr_api.pdb
+++ b/bin/win32/openvr_api.pdb
Binary files differ
diff --git a/bin/win64/openvr_api.dll b/bin/win64/openvr_api.dll
index 114a983..e46b14a 100644
--- a/bin/win64/openvr_api.dll
+++ b/bin/win64/openvr_api.dll
Binary files differ
diff --git a/bin/win64/openvr_api.pdb b/bin/win64/openvr_api.pdb
index 8996cc5..711271a 100644
--- a/bin/win64/openvr_api.pdb
+++ b/bin/win64/openvr_api.pdb
Binary files differ
diff --git a/headers/openvr.h b/headers/openvr.h
index c9e1f5d..704f757 100644
--- a/headers/openvr.h
+++ b/headers/openvr.h
@@ -15,8 +15,8 @@
namespace vr
{
static const uint32_t k_nSteamVRVersionMajor = 1;
- static const uint32_t k_nSteamVRVersionMinor = 6;
- static const uint32_t k_nSteamVRVersionBuild = 10;
+ static const uint32_t k_nSteamVRVersionMinor = 7;
+ static const uint32_t k_nSteamVRVersionBuild = 15;
} // namespace vr
// vrtypes.h
@@ -432,6 +432,7 @@ enum ETrackedDeviceProperty
Prop_ExpectedControllerType_String = 2074,
Prop_HmdTrackingStyle_Int32 = 2075, // one of EHmdTrackingStyle
Prop_DriverProvidedChaperoneVisibility_Bool = 2076,
+ Prop_HmdProvidesDisplaySettings_Bool = 2077,
Prop_DisplayAvailableFrameRates_Float_Array = 2080, // populated by compositor from actual EDID list when available from GPU driver
@@ -483,11 +484,13 @@ enum ETrackedDeviceProperty
Prop_NamedIconPathDeviceNotReady_String = 5006, // {driver}/icons/icon_filename - PNG for static icon, or GIF for animation, 50x32 for headsets and 32x32 for others
Prop_NamedIconPathDeviceStandby_String = 5007, // {driver}/icons/icon_filename - PNG for static icon, or GIF for animation, 50x32 for headsets and 32x32 for others
Prop_NamedIconPathDeviceAlertLow_String = 5008, // {driver}/icons/icon_filename - PNG for static icon, or GIF for animation, 50x32 for headsets and 32x32 for others
+ Prop_NamedIconPathDeviceStandbyAlert_String = 5009, // {driver}/icons/icon_filename - PNG for static icon, or GIF for animation, 50x32 for headsets and 32x32 for others
// Properties that are used by helpers, but are opaque to applications
Prop_DisplayHiddenArea_Binary_Start = 5100,
Prop_DisplayHiddenArea_Binary_End = 5150,
Prop_ParentContainer = 5151,
+ Prop_OverrideContainer_Uint64 = 5152,
// Properties that are unique to drivers
Prop_UserConfigPath_String = 6000,
@@ -807,8 +810,8 @@ enum EVREventType
VREvent_ProcessConnected = 1306,
VREvent_ProcessDisconnected = 1307,
- VREvent_Compositor_MirrorWindowShown = 1400,
- VREvent_Compositor_MirrorWindowHidden = 1401,
+ //VREvent_Compositor_MirrorWindowShown = 1400, // DEPRECATED
+ //VREvent_Compositor_MirrorWindowHidden = 1401, // DEPRECATED
VREvent_Compositor_ChaperoneBoundsShown = 1410,
VREvent_Compositor_ChaperoneBoundsHidden = 1411,
VREvent_Compositor_DisplayDisconnected = 1412,
@@ -847,6 +850,9 @@ enum EVREventType
VREvent_SystemReport_Started = 1900, // user or system initiated generation of a system report. broadcast
+ VREvent_Monitor_ShowHeadsetView = 2000, // data is process
+ VREvent_Monitor_HideHeadsetView = 2001, // data is process
+
// Vendors are free to expose private events in this reserved region
VREvent_VendorSpecific_Reserved_Start = 10000,
VREvent_VendorSpecific_Reserved_End = 19999,
@@ -1546,6 +1552,7 @@ enum EVRInitError
VRInitError_Driver_HmdDriverIdOutOfBounds = 211,
VRInitError_Driver_HmdDisplayMirrored = 212,
VRInitError_Driver_HmdDisplayNotFoundLaptop = 213,
+ // Never make error 259 because we return it from main and it would conflict with STILL_ACTIVE
VRInitError_IPC_ServerInitFailed = 300,
VRInitError_IPC_ConnectFailed = 301,
@@ -1747,7 +1754,7 @@ struct CameraVideoStreamFrameHeader_t
uint32_t nFrameSequence;
- TrackedDevicePose_t standingTrackedDevicePose;
+ TrackedDevicePose_t trackedDevicePose;
uint64_t ulFrameExposureTime; // mid-point of the exposure of the image in host system ticks
};
@@ -2300,6 +2307,7 @@ namespace vr
VRApplicationProperty_IsInstanced_Bool = 62,
VRApplicationProperty_IsInternal_Bool = 63,
VRApplicationProperty_WantsCompositorPauseInStandby_Bool = 64,
+ VRApplicationProperty_IsHidden_Bool = 65,
VRApplicationProperty_LastLaunchTime_Uint64 = 70,
};
@@ -2616,7 +2624,10 @@ namespace vr
static const char * const k_pch_SteamVR_MotionSmoothingOverride_Int32 = "motionSmoothingOverride";
static const char * const k_pch_SteamVR_ForceFadeOnBadTracking_Bool = "forceFadeOnBadTracking";
static const char * const k_pch_SteamVR_DefaultMirrorView_Int32 = "mirrorView";
- static const char * const k_pch_SteamVR_ShowMirrorView_Bool = "showMirrorView";
+ static const char * const k_pch_SteamVR_ShowLegacyMirrorView_Bool = "showLegacyMirrorView";
+ static const char * const k_pch_SteamVR_MirrorViewVisibility_Bool = "showMirrorView";
+ static const char * const k_pch_SteamVR_MirrorViewDisplayMode_Int32 = "mirrorViewDisplayMode";
+ static const char * const k_pch_SteamVR_MirrorViewEye_Int32 = "mirrorViewEye";
static const char * const k_pch_SteamVR_MirrorViewGeometry_String = "mirrorViewGeometry";
static const char * const k_pch_SteamVR_MirrorViewGeometryMaximized_String = "mirrorViewGeometryMaximized";
static const char * const k_pch_SteamVR_StartMonitorFromAppLaunch = "startMonitorFromAppLaunch";
@@ -2645,6 +2656,9 @@ namespace vr
static const char * const k_pch_SteamVR_HmdDisplayColorGainR_Float = "hmdDisplayColorGainR";
static const char * const k_pch_SteamVR_HmdDisplayColorGainG_Float = "hmdDisplayColorGainG";
static const char * const k_pch_SteamVR_HmdDisplayColorGainB_Float = "hmdDisplayColorGainB";
+ static const char * const k_pch_SteamVR_CustomIconStyle_String = "customIconStyle";
+ static const char * const k_pch_SteamVR_CustomOffIconStyle_String = "customOffIconStyle";
+ static const char * const k_pch_SteamVR_CustomIconForceUpdate_String = "customIconForceUpdate";
//-----------------------------------------------------------------------------
// direct mode keys
@@ -2774,6 +2788,7 @@ namespace vr
static const char * const k_pch_Dashboard_UseWebSettings = "useWebSettings";
static const char * const k_pch_Dashboard_UseWebIPD = "useWebIPD";
static const char * const k_pch_Dashboard_UseWebPowerMenu = "useWebPowerMenu";
+ static const char * const k_pch_Dashboard_UseWebNotifications = "useWebNotifications";
//-----------------------------------------------------------------------------
// model skin keys
@@ -3186,14 +3201,14 @@ public:
/** Returns true if the current process has the scene focus */
virtual bool CanRenderScene() = 0;
- /** Opens the headset view (as either a window or docked widget depending on user's preferences) that displays what the user
+ /** DEPRECATED: Opens the headset view (as either a window or docked widget depending on user's preferences) that displays what the user
* sees in the headset. */
virtual void ShowMirrorWindow() = 0;
- /** Closes the headset view, either as a window or docked widget. */
+ /** DEPRECATED: Closes the headset view, either as a window or docked widget. */
virtual void HideMirrorWindow() = 0;
- /** Returns true if the headset view (either as a window or docked widget) is shown. */
+ /** DEPRECATED: Returns true if the headset view (either as a window or docked widget) is shown. */
virtual bool IsMirrorWindowVisible() = 0;
/** Writes back buffer and stereo left/right pair from the application to a 'screenshots' folder in the SteamVR runtime root. */
@@ -3406,10 +3421,6 @@ namespace vr
{
VROverlayFlags_None = 0,
- // The following only take effect when rendered using the high quality render path (see SetHighQualityOverlay).
- VROverlayFlags_Curved = 1,
- VROverlayFlags_RGSS4X = 2,
-
// Set this flag on a dashboard overlay to prevent a tab from showing up for that overlay
VROverlayFlags_NoDashboardTab = 3,
@@ -3458,6 +3469,9 @@ namespace vr
// If this is set, the overlay texture will be protected content, preventing unauthorized reads.
VROverlayFlags_ProtectedContent = 18,
+
+ // not used for anything. This is useful for iterating over flag types.
+ VROverlayFlags_Max
};
enum VRMessageOverlayResponse
@@ -3564,17 +3578,6 @@ namespace vr
* automatically destroyed. */
virtual EVROverlayError DestroyOverlay( VROverlayHandle_t ulOverlayHandle ) = 0;
- /** Specify which overlay to use the high quality render path. This overlay will be composited in during the distortion pass which
- * results in it drawing on top of everything else, but also at a higher quality as it samples the source texture directly rather than
- * rasterizing into each eye's render texture first. Because if this, only one of these is supported at any given time. It is most useful
- * for overlays that are expected to take up most of the user's view (e.g. streaming video).
- * This mode does not support mouse input to your overlay. */
- virtual EVROverlayError SetHighQualityOverlay( VROverlayHandle_t ulOverlayHandle ) = 0;
-
- /** Returns the overlay handle of the current overlay being rendered using the single high quality overlay render path.
- * Otherwise it will return k_ulOverlayHandleInvalid. */
- virtual vr::VROverlayHandle_t GetHighQualityOverlay() = 0;
-
/** Fills the provided buffer with the string key of the overlay. Returns the size of buffer required to store the key, including
* the terminating null character. k_unVROverlayMaxKeyLength will be enough bytes to fit the string. */
virtual uint32_t GetOverlayKey( VROverlayHandle_t ulOverlayHandle, VR_OUT_STRING() char *pchValue, uint32_t unBufferSize, EVROverlayError *pError = 0L ) = 0;
@@ -3877,7 +3880,7 @@ namespace vr
virtual void CloseMessageOverlay() = 0;
};
- static const char * const IVROverlay_Version = "IVROverlay_019";
+ static const char * const IVROverlay_Version = "IVROverlay_020";
} // namespace vr
@@ -4167,9 +4170,11 @@ public:
/** Access a shared GL texture for the specified tracked camera stream */
virtual vr::EVRTrackedCameraError GetVideoStreamTextureGL( vr::TrackedCameraHandle_t hTrackedCamera, vr::EVRTrackedCameraFrameType eFrameType, vr::glUInt_t *pglTextureId, vr::CameraVideoStreamFrameHeader_t *pFrameHeader, uint32_t nFrameHeaderSize ) = 0;
virtual vr::EVRTrackedCameraError ReleaseVideoStreamTextureGL( vr::TrackedCameraHandle_t hTrackedCamera, vr::glUInt_t glTextureId ) = 0;
+ virtual void SetCameraTrackingSpace( vr::ETrackingUniverseOrigin eUniverse ) = 0;
+ virtual vr::ETrackingUniverseOrigin GetCameraTrackingSpace( ) = 0;
};
-static const char * const IVRTrackedCamera_Version = "IVRTrackedCamera_005";
+static const char * const IVRTrackedCamera_Version = "IVRTrackedCamera_006";
} // namespace vr
diff --git a/headers/openvr_api.cs b/headers/openvr_api.cs
index f96ad80..7fcb06c 100644
--- a/headers/openvr_api.cs
+++ b/headers/openvr_api.cs
@@ -340,6 +340,16 @@ public struct IVRTrackedCamera
[MarshalAs(UnmanagedType.FunctionPtr)]
internal _ReleaseVideoStreamTextureGL ReleaseVideoStreamTextureGL;
+ [UnmanagedFunctionPointer(CallingConvention.StdCall)]
+ internal delegate void _SetCameraTrackingSpace(ETrackingUniverseOrigin eUniverse);
+ [MarshalAs(UnmanagedType.FunctionPtr)]
+ internal _SetCameraTrackingSpace SetCameraTrackingSpace;
+
+ [UnmanagedFunctionPointer(CallingConvention.StdCall)]
+ internal delegate ETrackingUniverseOrigin _GetCameraTrackingSpace();
+ [MarshalAs(UnmanagedType.FunctionPtr)]
+ internal _GetCameraTrackingSpace GetCameraTrackingSpace;
+
}
[StructLayout(LayoutKind.Sequential)]
@@ -906,16 +916,6 @@ public struct IVROverlay
internal _DestroyOverlay DestroyOverlay;
[UnmanagedFunctionPointer(CallingConvention.StdCall)]
- internal delegate EVROverlayError _SetHighQualityOverlay(ulong ulOverlayHandle);
- [MarshalAs(UnmanagedType.FunctionPtr)]
- internal _SetHighQualityOverlay SetHighQualityOverlay;
-
- [UnmanagedFunctionPointer(CallingConvention.StdCall)]
- internal delegate ulong _GetHighQualityOverlay();
- [MarshalAs(UnmanagedType.FunctionPtr)]
- internal _GetHighQualityOverlay GetHighQualityOverlay;
-
- [UnmanagedFunctionPointer(CallingConvention.StdCall)]
internal delegate uint _GetOverlayKey(ulong ulOverlayHandle, System.Text.StringBuilder pchValue, uint unBufferSize, ref EVROverlayError pError);
[MarshalAs(UnmanagedType.FunctionPtr)]
internal _GetOverlayKey GetOverlayKey;
@@ -2223,6 +2223,15 @@ public class CVRTrackedCamera
EVRTrackedCameraError result = FnTable.ReleaseVideoStreamTextureGL(hTrackedCamera,glTextureId);
return result;
}
+ public void SetCameraTrackingSpace(ETrackingUniverseOrigin eUniverse)
+ {
+ FnTable.SetCameraTrackingSpace(eUniverse);
+ }
+ public ETrackingUniverseOrigin GetCameraTrackingSpace()
+ {
+ ETrackingUniverseOrigin result = FnTable.GetCameraTrackingSpace();
+ return result;
+ }
}
@@ -2793,16 +2802,6 @@ public class CVROverlay
EVROverlayError result = FnTable.DestroyOverlay(ulOverlayHandle);
return result;
}
- public EVROverlayError SetHighQualityOverlay(ulong ulOverlayHandle)
- {
- EVROverlayError result = FnTable.SetHighQualityOverlay(ulOverlayHandle);
- return result;
- }
- public ulong GetHighQualityOverlay()
- {
- ulong result = FnTable.GetHighQualityOverlay();
- return result;
- }
public uint GetOverlayKey(ulong ulOverlayHandle,System.Text.StringBuilder pchValue,uint unBufferSize,ref EVROverlayError pError)
{
uint result = FnTable.GetOverlayKey(ulOverlayHandle,pchValue,unBufferSize,ref pError);
@@ -4016,6 +4015,7 @@ public enum ETrackedDeviceProperty
Prop_ExpectedControllerType_String = 2074,
Prop_HmdTrackingStyle_Int32 = 2075,
Prop_DriverProvidedChaperoneVisibility_Bool = 2076,
+ Prop_HmdProvidesDisplaySettings_Bool = 2077,
Prop_DisplayAvailableFrameRates_Float_Array = 2080,
Prop_DisplaySupportsMultipleFramerates_Bool = 2081,
Prop_DisplayColorMultLeft_Vector3 = 2082,
@@ -4056,9 +4056,11 @@ public enum ETrackedDeviceProperty
Prop_NamedIconPathDeviceNotReady_String = 5006,
Prop_NamedIconPathDeviceStandby_String = 5007,
Prop_NamedIconPathDeviceAlertLow_String = 5008,
+ Prop_NamedIconPathDeviceStandbyAlert_String = 5009,
Prop_DisplayHiddenArea_Binary_Start = 5100,
Prop_DisplayHiddenArea_Binary_End = 5150,
Prop_ParentContainer = 5151,
+ Prop_OverrideContainer_Uint64 = 5152,
Prop_UserConfigPath_String = 6000,
Prop_InstallPath_String = 6001,
Prop_HasDisplayComponent_Bool = 6002,
@@ -4252,8 +4254,6 @@ public enum EVREventType
VREvent_ApplicationTransitionNewAppLaunchComplete = 1305,
VREvent_ProcessConnected = 1306,
VREvent_ProcessDisconnected = 1307,
- VREvent_Compositor_MirrorWindowShown = 1400,
- VREvent_Compositor_MirrorWindowHidden = 1401,
VREvent_Compositor_ChaperoneBoundsShown = 1410,
VREvent_Compositor_ChaperoneBoundsHidden = 1411,
VREvent_Compositor_DisplayDisconnected = 1412,
@@ -4285,6 +4285,8 @@ public enum EVREventType
VREvent_SpatialAnchors_RequestPoseUpdate = 1802,
VREvent_SpatialAnchors_RequestDescriptorUpdate = 1803,
VREvent_SystemReport_Started = 1900,
+ VREvent_Monitor_ShowHeadsetView = 2000,
+ VREvent_Monitor_HideHeadsetView = 2001,
VREvent_VendorSpecific_Reserved_Start = 10000,
VREvent_VendorSpecific_Reserved_End = 19999,
}
@@ -4777,6 +4779,7 @@ public enum EVRApplicationProperty
IsInstanced_Bool = 62,
IsInternal_Bool = 63,
WantsCompositorPauseInStandby_Bool = 64,
+ IsHidden_Bool = 65,
LastLaunchTime_Uint64 = 70,
}
public enum EVRApplicationTransitionState
@@ -4845,8 +4848,6 @@ public enum VROverlayTransformType
public enum VROverlayFlags
{
None = 0,
- Curved = 1,
- RGSS4X = 2,
NoDashboardTab = 3,
AcceptsGamepadEvents = 4,
ShowGamepadFocus = 5,
@@ -4863,6 +4864,7 @@ public enum VROverlayFlags
MakeOverlaysInteractiveIfVisible = 16,
SendVRSmoothScrollEvents = 17,
ProtectedContent = 18,
+ Max = 19,
}
public enum VRMessageOverlayResponse
{
@@ -5536,7 +5538,7 @@ public enum EVRDebugError
public uint nHeight;
public uint nBytesPerPixel;
public uint nFrameSequence;
- public TrackedDevicePose_t standingTrackedDevicePose;
+ public TrackedDevicePose_t trackedDevicePose;
public ulong ulFrameExposureTime;
}
[StructLayout(LayoutKind.Sequential)] public struct Compositor_FrameTiming
@@ -6595,7 +6597,7 @@ public class OpenVR
public const uint k_unScreenshotHandleInvalid = 0;
public const string IVRSystem_Version = "IVRSystem_020";
public const string IVRExtendedDisplay_Version = "IVRExtendedDisplay_001";
- public const string IVRTrackedCamera_Version = "IVRTrackedCamera_005";
+ public const string IVRTrackedCamera_Version = "IVRTrackedCamera_006";
public const uint k_unMaxApplicationKeyLength = 128;
public const string k_pch_MimeType_HomeApp = "vr/home";
public const string k_pch_MimeType_GameTheater = "vr/game_theater";
@@ -6607,7 +6609,7 @@ public class OpenVR
public const uint k_unVROverlayMaxNameLength = 128;
public const uint k_unMaxOverlayCount = 64;
public const uint k_unMaxOverlayIntersectionMaskPrimitivesCount = 32;
- public const string IVROverlay_Version = "IVROverlay_019";
+ public const string IVROverlay_Version = "IVROverlay_020";
public const string k_pch_Controller_Component_GDC2015 = "gdc2015";
public const string k_pch_Controller_Component_Base = "base";
public const string k_pch_Controller_Component_Tip = "tip";
@@ -6647,7 +6649,10 @@ public class OpenVR
public const string k_pch_SteamVR_MotionSmoothingOverride_Int32 = "motionSmoothingOverride";
public const string k_pch_SteamVR_ForceFadeOnBadTracking_Bool = "forceFadeOnBadTracking";
public const string k_pch_SteamVR_DefaultMirrorView_Int32 = "mirrorView";
- public const string k_pch_SteamVR_ShowMirrorView_Bool = "showMirrorView";
+ public const string k_pch_SteamVR_ShowLegacyMirrorView_Bool = "showLegacyMirrorView";
+ public const string k_pch_SteamVR_MirrorViewVisibility_Bool = "showMirrorView";
+ public const string k_pch_SteamVR_MirrorViewDisplayMode_Int32 = "mirrorViewDisplayMode";
+ public const string k_pch_SteamVR_MirrorViewEye_Int32 = "mirrorViewEye";
public const string k_pch_SteamVR_MirrorViewGeometry_String = "mirrorViewGeometry";
public const string k_pch_SteamVR_MirrorViewGeometryMaximized_String = "mirrorViewGeometryMaximized";
public const string k_pch_SteamVR_StartMonitorFromAppLaunch = "startMonitorFromAppLaunch";
@@ -6676,6 +6681,9 @@ public class OpenVR
public const string k_pch_SteamVR_HmdDisplayColorGainR_Float = "hmdDisplayColorGainR";
public const string k_pch_SteamVR_HmdDisplayColorGainG_Float = "hmdDisplayColorGainG";
public const string k_pch_SteamVR_HmdDisplayColorGainB_Float = "hmdDisplayColorGainB";
+ public const string k_pch_SteamVR_CustomIconStyle_String = "customIconStyle";
+ public const string k_pch_SteamVR_CustomOffIconStyle_String = "customOffIconStyle";
+ public const string k_pch_SteamVR_CustomIconForceUpdate_String = "customIconForceUpdate";
public const string k_pch_DirectMode_Section = "direct_mode";
public const string k_pch_DirectMode_Enable_Bool = "enable";
public const string k_pch_DirectMode_Count_Int32 = "count";
@@ -6769,6 +6777,7 @@ public class OpenVR
public const string k_pch_Dashboard_UseWebSettings = "useWebSettings";
public const string k_pch_Dashboard_UseWebIPD = "useWebIPD";
public const string k_pch_Dashboard_UseWebPowerMenu = "useWebPowerMenu";
+ public const string k_pch_Dashboard_UseWebNotifications = "useWebNotifications";
public const string k_pch_modelskin_Section = "modelskins";
public const string k_pch_Driver_Enable_Bool = "enable";
public const string k_pch_Driver_LoadPriority_Int32 = "loadPriority";
diff --git a/headers/openvr_api.json b/headers/openvr_api.json
index 89510f0..4cb3467 100644
--- a/headers/openvr_api.json
+++ b/headers/openvr_api.json
@@ -220,6 +220,7 @@
,{"name": "Prop_ExpectedControllerType_String","value": "2074"}
,{"name": "Prop_HmdTrackingStyle_Int32","value": "2075"}
,{"name": "Prop_DriverProvidedChaperoneVisibility_Bool","value": "2076"}
+ ,{"name": "Prop_HmdProvidesDisplaySettings_Bool","value": "2077"}
,{"name": "Prop_DisplayAvailableFrameRates_Float_Array","value": "2080"}
,{"name": "Prop_DisplaySupportsMultipleFramerates_Bool","value": "2081"}
,{"name": "Prop_DisplayColorMultLeft_Vector3","value": "2082"}
@@ -260,9 +261,11 @@
,{"name": "Prop_NamedIconPathDeviceNotReady_String","value": "5006"}
,{"name": "Prop_NamedIconPathDeviceStandby_String","value": "5007"}
,{"name": "Prop_NamedIconPathDeviceAlertLow_String","value": "5008"}
+ ,{"name": "Prop_NamedIconPathDeviceStandbyAlert_String","value": "5009"}
,{"name": "Prop_DisplayHiddenArea_Binary_Start","value": "5100"}
,{"name": "Prop_DisplayHiddenArea_Binary_End","value": "5150"}
,{"name": "Prop_ParentContainer","value": "5151"}
+ ,{"name": "Prop_OverrideContainer_Uint64","value": "5152"}
,{"name": "Prop_UserConfigPath_String","value": "6000"}
,{"name": "Prop_InstallPath_String","value": "6001"}
,{"name": "Prop_HasDisplayComponent_Bool","value": "6002"}
@@ -451,8 +454,6 @@
,{"name": "VREvent_ApplicationTransitionNewAppLaunchComplete","value": "1305"}
,{"name": "VREvent_ProcessConnected","value": "1306"}
,{"name": "VREvent_ProcessDisconnected","value": "1307"}
- ,{"name": "VREvent_Compositor_MirrorWindowShown","value": "1400"}
- ,{"name": "VREvent_Compositor_MirrorWindowHidden","value": "1401"}
,{"name": "VREvent_Compositor_ChaperoneBoundsShown","value": "1410"}
,{"name": "VREvent_Compositor_ChaperoneBoundsHidden","value": "1411"}
,{"name": "VREvent_Compositor_DisplayDisconnected","value": "1412"}
@@ -484,6 +485,8 @@
,{"name": "VREvent_SpatialAnchors_RequestPoseUpdate","value": "1802"}
,{"name": "VREvent_SpatialAnchors_RequestDescriptorUpdate","value": "1803"}
,{"name": "VREvent_SystemReport_Started","value": "1900"}
+ ,{"name": "VREvent_Monitor_ShowHeadsetView","value": "2000"}
+ ,{"name": "VREvent_Monitor_HideHeadsetView","value": "2001"}
,{"name": "VREvent_VendorSpecific_Reserved_Start","value": "10000"}
,{"name": "VREvent_VendorSpecific_Reserved_End","value": "19999"}
]}
@@ -946,6 +949,7 @@
,{"name": "VRApplicationProperty_IsInstanced_Bool","value": "62"}
,{"name": "VRApplicationProperty_IsInternal_Bool","value": "63"}
,{"name": "VRApplicationProperty_WantsCompositorPauseInStandby_Bool","value": "64"}
+ ,{"name": "VRApplicationProperty_IsHidden_Bool","value": "65"}
,{"name": "VRApplicationProperty_LastLaunchTime_Uint64","value": "70"}
]}
, {"enumname": "vr::EVRApplicationTransitionState","values": [
@@ -1005,8 +1009,6 @@
]}
, {"enumname": "vr::VROverlayFlags","values": [
{"name": "VROverlayFlags_None","value": "0"}
- ,{"name": "VROverlayFlags_Curved","value": "1"}
- ,{"name": "VROverlayFlags_RGSS4X","value": "2"}
,{"name": "VROverlayFlags_NoDashboardTab","value": "3"}
,{"name": "VROverlayFlags_AcceptsGamepadEvents","value": "4"}
,{"name": "VROverlayFlags_ShowGamepadFocus","value": "5"}
@@ -1023,6 +1025,7 @@
,{"name": "VROverlayFlags_MakeOverlaysInteractiveIfVisible","value": "16"}
,{"name": "VROverlayFlags_SendVRSmoothScrollEvents","value": "17"}
,{"name": "VROverlayFlags_ProtectedContent","value": "18"}
+ ,{"name": "VROverlayFlags_Max","value": "19"}
]}
, {"enumname": "vr::VRMessageOverlayResponse","values": [
{"name": "VRMessageOverlayResponse_ButtonPress_0","value": "0"}
@@ -1246,7 +1249,7 @@
,{
"constname": "IVRExtendedDisplay_Version","consttype": "const char *const", "constval": "IVRExtendedDisplay_001"}
,{
- "constname": "IVRTrackedCamera_Version","consttype": "const char *const", "constval": "IVRTrackedCamera_005"}
+ "constname": "IVRTrackedCamera_Version","consttype": "const char *const", "constval": "IVRTrackedCamera_006"}
,{
"constname": "k_unMaxApplicationKeyLength","consttype": "const uint32_t", "constval": "128"}
,{
@@ -1270,7 +1273,7 @@
,{
"constname": "k_unMaxOverlayIntersectionMaskPrimitivesCount","consttype": "const uint32_t", "constval": "32"}
,{
- "constname": "IVROverlay_Version","consttype": "const char *const", "constval": "IVROverlay_019"}
+ "constname": "IVROverlay_Version","consttype": "const char *const", "constval": "IVROverlay_020"}
,{
"constname": "k_pch_Controller_Component_GDC2015","consttype": "const char *const", "constval": "gdc2015"}
,{
@@ -1350,7 +1353,13 @@
,{
"constname": "k_pch_SteamVR_DefaultMirrorView_Int32","consttype": "const char *const", "constval": "mirrorView"}
,{
- "constname": "k_pch_SteamVR_ShowMirrorView_Bool","consttype": "const char *const", "constval": "showMirrorView"}
+ "constname": "k_pch_SteamVR_ShowLegacyMirrorView_Bool","consttype": "const char *const", "constval": "showLegacyMirrorView"}
+,{
+ "constname": "k_pch_SteamVR_MirrorViewVisibility_Bool","consttype": "const char *const", "constval": "showMirrorView"}
+,{
+ "constname": "k_pch_SteamVR_MirrorViewDisplayMode_Int32","consttype": "const char *const", "constval": "mirrorViewDisplayMode"}
+,{
+ "constname": "k_pch_SteamVR_MirrorViewEye_Int32","consttype": "const char *const", "constval": "mirrorViewEye"}
,{
"constname": "k_pch_SteamVR_MirrorViewGeometry_String","consttype": "const char *const", "constval": "mirrorViewGeometry"}
,{
@@ -1408,6 +1417,12 @@
,{
"constname": "k_pch_SteamVR_HmdDisplayColorGainB_Float","consttype": "const char *const", "constval": "hmdDisplayColorGainB"}
,{
+ "constname": "k_pch_SteamVR_CustomIconStyle_String","consttype": "const char *const", "constval": "customIconStyle"}
+,{
+ "constname": "k_pch_SteamVR_CustomOffIconStyle_String","consttype": "const char *const", "constval": "customOffIconStyle"}
+,{
+ "constname": "k_pch_SteamVR_CustomIconForceUpdate_String","consttype": "const char *const", "constval": "customIconForceUpdate"}
+,{
"constname": "k_pch_DirectMode_Section","consttype": "const char *const", "constval": "direct_mode"}
,{
"constname": "k_pch_DirectMode_Enable_Bool","consttype": "const char *const", "constval": "enable"}
@@ -1594,6 +1609,8 @@
,{
"constname": "k_pch_Dashboard_UseWebPowerMenu","consttype": "const char *const", "constval": "useWebPowerMenu"}
,{
+ "constname": "k_pch_Dashboard_UseWebNotifications","consttype": "const char *const", "constval": "useWebNotifications"}
+,{
"constname": "k_pch_modelskin_Section","consttype": "const char *const", "constval": "modelskins"}
,{
"constname": "k_pch_Driver_Enable_Bool","consttype": "const char *const", "constval": "enable"}
@@ -1921,7 +1938,7 @@
{ "fieldname": "nHeight", "fieldtype": "uint32_t"},
{ "fieldname": "nBytesPerPixel", "fieldtype": "uint32_t"},
{ "fieldname": "nFrameSequence", "fieldtype": "uint32_t"},
-{ "fieldname": "standingTrackedDevicePose", "fieldtype": "struct vr::TrackedDevicePose_t"},
+{ "fieldname": "trackedDevicePose", "fieldtype": "struct vr::TrackedDevicePose_t"},
{ "fieldname": "ulFrameExposureTime", "fieldtype": "uint64_t"}]}
,{"struct": "vr::Compositor_FrameTiming","fields": [
{ "fieldname": "m_nSize", "fieldtype": "uint32_t"},
@@ -2659,6 +2676,19 @@
]
}
,{
+ "classname": "vr::IVRTrackedCamera",
+ "methodname": "SetCameraTrackingSpace",
+ "returntype": "void",
+ "params": [
+{ "paramname": "eUniverse" ,"paramtype": "vr::ETrackingUniverseOrigin"}
+ ]
+}
+,{
+ "classname": "vr::IVRTrackedCamera",
+ "methodname": "GetCameraTrackingSpace",
+ "returntype": "vr::ETrackingUniverseOrigin"
+}
+,{
"classname": "vr::IVRApplications",
"methodname": "AddApplicationManifest",
"returntype": "vr::EVRApplicationError",
@@ -3497,19 +3527,6 @@
}
,{
"classname": "vr::IVROverlay",
- "methodname": "SetHighQualityOverlay",
- "returntype": "vr::EVROverlayError",
- "params": [
-{ "paramname": "ulOverlayHandle" ,"paramtype": "vr::VROverlayHandle_t"}
- ]
-}
-,{
- "classname": "vr::IVROverlay",
- "methodname": "GetHighQualityOverlay",
- "returntype": "vr::VROverlayHandle_t"
-}
-,{
- "classname": "vr::IVROverlay",
"methodname": "GetOverlayKey",
"returntype": "uint32_t",
"params": [
diff --git a/headers/openvr_capi.h b/headers/openvr_capi.h
index 5295a4e..f6743de 100644
--- a/headers/openvr_capi.h
+++ b/headers/openvr_capi.h
@@ -105,7 +105,7 @@ static const unsigned int k_unMaxDistortionFunctionParameters = 8;
static const unsigned int k_unScreenshotHandleInvalid = 0;
static const char * IVRSystem_Version = "IVRSystem_020";
static const char * IVRExtendedDisplay_Version = "IVRExtendedDisplay_001";
-static const char * IVRTrackedCamera_Version = "IVRTrackedCamera_005";
+static const char * IVRTrackedCamera_Version = "IVRTrackedCamera_006";
static const unsigned int k_unMaxApplicationKeyLength = 128;
static const char * k_pch_MimeType_HomeApp = "vr/home";
static const char * k_pch_MimeType_GameTheater = "vr/game_theater";
@@ -117,7 +117,7 @@ static const unsigned int k_unVROverlayMaxKeyLength = 128;
static const unsigned int k_unVROverlayMaxNameLength = 128;
static const unsigned int k_unMaxOverlayCount = 64;
static const unsigned int k_unMaxOverlayIntersectionMaskPrimitivesCount = 32;
-static const char * IVROverlay_Version = "IVROverlay_019";
+static const char * IVROverlay_Version = "IVROverlay_020";
static const char * k_pch_Controller_Component_GDC2015 = "gdc2015";
static const char * k_pch_Controller_Component_Base = "base";
static const char * k_pch_Controller_Component_Tip = "tip";
@@ -157,7 +157,10 @@ static const char * k_pch_SteamVR_MotionSmoothing_Bool = "motionSmoothing";
static const char * k_pch_SteamVR_MotionSmoothingOverride_Int32 = "motionSmoothingOverride";
static const char * k_pch_SteamVR_ForceFadeOnBadTracking_Bool = "forceFadeOnBadTracking";
static const char * k_pch_SteamVR_DefaultMirrorView_Int32 = "mirrorView";
-static const char * k_pch_SteamVR_ShowMirrorView_Bool = "showMirrorView";
+static const char * k_pch_SteamVR_ShowLegacyMirrorView_Bool = "showLegacyMirrorView";
+static const char * k_pch_SteamVR_MirrorViewVisibility_Bool = "showMirrorView";
+static const char * k_pch_SteamVR_MirrorViewDisplayMode_Int32 = "mirrorViewDisplayMode";
+static const char * k_pch_SteamVR_MirrorViewEye_Int32 = "mirrorViewEye";
static const char * k_pch_SteamVR_MirrorViewGeometry_String = "mirrorViewGeometry";
static const char * k_pch_SteamVR_MirrorViewGeometryMaximized_String = "mirrorViewGeometryMaximized";
static const char * k_pch_SteamVR_StartMonitorFromAppLaunch = "startMonitorFromAppLaunch";
@@ -186,6 +189,9 @@ static const char * k_pch_SteamVR_LastVersionNoticeDate = "lastVersionNoticeDate
static const char * k_pch_SteamVR_HmdDisplayColorGainR_Float = "hmdDisplayColorGainR";
static const char * k_pch_SteamVR_HmdDisplayColorGainG_Float = "hmdDisplayColorGainG";
static const char * k_pch_SteamVR_HmdDisplayColorGainB_Float = "hmdDisplayColorGainB";
+static const char * k_pch_SteamVR_CustomIconStyle_String = "customIconStyle";
+static const char * k_pch_SteamVR_CustomOffIconStyle_String = "customOffIconStyle";
+static const char * k_pch_SteamVR_CustomIconForceUpdate_String = "customIconForceUpdate";
static const char * k_pch_DirectMode_Section = "direct_mode";
static const char * k_pch_DirectMode_Enable_Bool = "enable";
static const char * k_pch_DirectMode_Count_Int32 = "count";
@@ -279,6 +285,7 @@ static const char * k_pch_Dashboard_UseWebDashboard = "useWebDashboard";
static const char * k_pch_Dashboard_UseWebSettings = "useWebSettings";
static const char * k_pch_Dashboard_UseWebIPD = "useWebIPD";
static const char * k_pch_Dashboard_UseWebPowerMenu = "useWebPowerMenu";
+static const char * k_pch_Dashboard_UseWebNotifications = "useWebNotifications";
static const char * k_pch_modelskin_Section = "modelskins";
static const char * k_pch_Driver_Enable_Bool = "enable";
static const char * k_pch_Driver_LoadPriority_Int32 = "loadPriority";
@@ -514,6 +521,7 @@ typedef enum ETrackedDeviceProperty
ETrackedDeviceProperty_Prop_ExpectedControllerType_String = 2074,
ETrackedDeviceProperty_Prop_HmdTrackingStyle_Int32 = 2075,
ETrackedDeviceProperty_Prop_DriverProvidedChaperoneVisibility_Bool = 2076,
+ ETrackedDeviceProperty_Prop_HmdProvidesDisplaySettings_Bool = 2077,
ETrackedDeviceProperty_Prop_DisplayAvailableFrameRates_Float_Array = 2080,
ETrackedDeviceProperty_Prop_DisplaySupportsMultipleFramerates_Bool = 2081,
ETrackedDeviceProperty_Prop_DisplayColorMultLeft_Vector3 = 2082,
@@ -554,9 +562,11 @@ typedef enum ETrackedDeviceProperty
ETrackedDeviceProperty_Prop_NamedIconPathDeviceNotReady_String = 5006,
ETrackedDeviceProperty_Prop_NamedIconPathDeviceStandby_String = 5007,
ETrackedDeviceProperty_Prop_NamedIconPathDeviceAlertLow_String = 5008,
+ ETrackedDeviceProperty_Prop_NamedIconPathDeviceStandbyAlert_String = 5009,
ETrackedDeviceProperty_Prop_DisplayHiddenArea_Binary_Start = 5100,
ETrackedDeviceProperty_Prop_DisplayHiddenArea_Binary_End = 5150,
ETrackedDeviceProperty_Prop_ParentContainer = 5151,
+ ETrackedDeviceProperty_Prop_OverrideContainer_Uint64 = 5152,
ETrackedDeviceProperty_Prop_UserConfigPath_String = 6000,
ETrackedDeviceProperty_Prop_InstallPath_String = 6001,
ETrackedDeviceProperty_Prop_HasDisplayComponent_Bool = 6002,
@@ -755,8 +765,6 @@ typedef enum EVREventType
EVREventType_VREvent_ApplicationTransitionNewAppLaunchComplete = 1305,
EVREventType_VREvent_ProcessConnected = 1306,
EVREventType_VREvent_ProcessDisconnected = 1307,
- EVREventType_VREvent_Compositor_MirrorWindowShown = 1400,
- EVREventType_VREvent_Compositor_MirrorWindowHidden = 1401,
EVREventType_VREvent_Compositor_ChaperoneBoundsShown = 1410,
EVREventType_VREvent_Compositor_ChaperoneBoundsHidden = 1411,
EVREventType_VREvent_Compositor_DisplayDisconnected = 1412,
@@ -788,6 +796,8 @@ typedef enum EVREventType
EVREventType_VREvent_SpatialAnchors_RequestPoseUpdate = 1802,
EVREventType_VREvent_SpatialAnchors_RequestDescriptorUpdate = 1803,
EVREventType_VREvent_SystemReport_Started = 1900,
+ EVREventType_VREvent_Monitor_ShowHeadsetView = 2000,
+ EVREventType_VREvent_Monitor_HideHeadsetView = 2001,
EVREventType_VREvent_VendorSpecific_Reserved_Start = 10000,
EVREventType_VREvent_VendorSpecific_Reserved_End = 19999,
} EVREventType;
@@ -1310,6 +1320,7 @@ typedef enum EVRApplicationProperty
EVRApplicationProperty_VRApplicationProperty_IsInstanced_Bool = 62,
EVRApplicationProperty_VRApplicationProperty_IsInternal_Bool = 63,
EVRApplicationProperty_VRApplicationProperty_WantsCompositorPauseInStandby_Bool = 64,
+ EVRApplicationProperty_VRApplicationProperty_IsHidden_Bool = 65,
EVRApplicationProperty_VRApplicationProperty_LastLaunchTime_Uint64 = 70,
} EVRApplicationProperty;
@@ -1387,8 +1398,6 @@ typedef enum VROverlayTransformType
typedef enum VROverlayFlags
{
VROverlayFlags_None = 0,
- VROverlayFlags_Curved = 1,
- VROverlayFlags_RGSS4X = 2,
VROverlayFlags_NoDashboardTab = 3,
VROverlayFlags_AcceptsGamepadEvents = 4,
VROverlayFlags_ShowGamepadFocus = 5,
@@ -1405,6 +1414,7 @@ typedef enum VROverlayFlags
VROverlayFlags_MakeOverlaysInteractiveIfVisible = 16,
VROverlayFlags_SendVRSmoothScrollEvents = 17,
VROverlayFlags_ProtectedContent = 18,
+ VROverlayFlags_Max = 19,
} VROverlayFlags;
typedef enum VRMessageOverlayResponse
@@ -2024,7 +2034,7 @@ typedef struct CameraVideoStreamFrameHeader_t
uint32_t nHeight;
uint32_t nBytesPerPixel;
uint32_t nFrameSequence;
- struct TrackedDevicePose_t standingTrackedDevicePose;
+ struct TrackedDevicePose_t trackedDevicePose;
uint64_t ulFrameExposureTime;
} CameraVideoStreamFrameHeader_t;
@@ -2422,6 +2432,8 @@ struct VR_IVRTrackedCamera_FnTable
EVRTrackedCameraError (OPENVR_FNTABLE_CALLTYPE *GetVideoStreamTextureD3D11)(TrackedCameraHandle_t hTrackedCamera, EVRTrackedCameraFrameType eFrameType, void * pD3D11DeviceOrResource, void ** ppD3D11ShaderResourceView, CameraVideoStreamFrameHeader_t * pFrameHeader, uint32_t nFrameHeaderSize);
EVRTrackedCameraError (OPENVR_FNTABLE_CALLTYPE *GetVideoStreamTextureGL)(TrackedCameraHandle_t hTrackedCamera, EVRTrackedCameraFrameType eFrameType, glUInt_t * pglTextureId, CameraVideoStreamFrameHeader_t * pFrameHeader, uint32_t nFrameHeaderSize);
EVRTrackedCameraError (OPENVR_FNTABLE_CALLTYPE *ReleaseVideoStreamTextureGL)(TrackedCameraHandle_t hTrackedCamera, glUInt_t glTextureId);
+ void (OPENVR_FNTABLE_CALLTYPE *SetCameraTrackingSpace)(ETrackingUniverseOrigin eUniverse);
+ ETrackingUniverseOrigin (OPENVR_FNTABLE_CALLTYPE *GetCameraTrackingSpace)();
};
struct VR_IVRApplications_FnTable
@@ -2550,8 +2562,6 @@ struct VR_IVROverlay_FnTable
EVROverlayError (OPENVR_FNTABLE_CALLTYPE *FindOverlay)(char * pchOverlayKey, VROverlayHandle_t * pOverlayHandle);
EVROverlayError (OPENVR_FNTABLE_CALLTYPE *CreateOverlay)(char * pchOverlayKey, char * pchOverlayName, VROverlayHandle_t * pOverlayHandle);
EVROverlayError (OPENVR_FNTABLE_CALLTYPE *DestroyOverlay)(VROverlayHandle_t ulOverlayHandle);
- EVROverlayError (OPENVR_FNTABLE_CALLTYPE *SetHighQualityOverlay)(VROverlayHandle_t ulOverlayHandle);
- VROverlayHandle_t (OPENVR_FNTABLE_CALLTYPE *GetHighQualityOverlay)();
uint32_t (OPENVR_FNTABLE_CALLTYPE *GetOverlayKey)(VROverlayHandle_t ulOverlayHandle, char * pchValue, uint32_t unBufferSize, EVROverlayError * pError);
uint32_t (OPENVR_FNTABLE_CALLTYPE *GetOverlayName)(VROverlayHandle_t ulOverlayHandle, char * pchValue, uint32_t unBufferSize, EVROverlayError * pError);
EVROverlayError (OPENVR_FNTABLE_CALLTYPE *SetOverlayName)(VROverlayHandle_t ulOverlayHandle, char * pchName);
diff --git a/lib/linux32/libopenvr_api.so b/lib/linux32/libopenvr_api.so
index e4b3dcd..44256c7 100755
--- a/lib/linux32/libopenvr_api.so
+++ b/lib/linux32/libopenvr_api.so
Binary files differ
diff --git a/lib/linux64/libopenvr_api.so b/lib/linux64/libopenvr_api.so
index e8d57d3..455cdcb 100755
--- a/lib/linux64/libopenvr_api.so
+++ b/lib/linux64/libopenvr_api.so
Binary files differ
diff --git a/samples/bin/linux32/libopenvr_api.so b/samples/bin/linux32/libopenvr_api.so
index c95dc19..db91225 100644
--- a/samples/bin/linux32/libopenvr_api.so
+++ b/samples/bin/linux32/libopenvr_api.so
Binary files differ
diff --git a/samples/bin/linux64/libopenvr_api.so b/samples/bin/linux64/libopenvr_api.so
index 2575362..3af38ac 100644
--- a/samples/bin/linux64/libopenvr_api.so
+++ b/samples/bin/linux64/libopenvr_api.so
Binary files differ
diff --git a/samples/bin/osx32/libopenvr_api.dylib b/samples/bin/osx32/libopenvr_api.dylib
index 059ac11..fae6aca 100644
--- a/samples/bin/osx32/libopenvr_api.dylib
+++ b/samples/bin/osx32/libopenvr_api.dylib
Binary files differ
diff --git a/samples/bin/win32/openvr_api.dll b/samples/bin/win32/openvr_api.dll
index 4b06e42..a9167aa 100644
--- a/samples/bin/win32/openvr_api.dll
+++ b/samples/bin/win32/openvr_api.dll
Binary files differ
diff --git a/samples/bin/win64/openvr_api.dll b/samples/bin/win64/openvr_api.dll
index 114a983..e46b14a 100644
--- a/samples/bin/win64/openvr_api.dll
+++ b/samples/bin/win64/openvr_api.dll
Binary files differ
diff --git a/samples/driver_sample/driver_sample.cpp b/samples/driver_sample/driver_sample.cpp
index 4f03534..9ad6990 100644
--- a/samples/driver_sample/driver_sample.cpp
+++ b/samples/driver_sample/driver_sample.cpp
@@ -103,7 +103,7 @@ void WatchdogThreadFunction( )
#else
// for the other platforms, just send one every five seconds
std::this_thread::sleep_for( std::chrono::seconds( 5 ) );
- vr::VRWatchdogHost()->WatchdogWakeUp();
+ vr::VRWatchdogHost()->WatchdogWakeUp( vr::TrackedDeviceClass_HMD );
#endif
}
}
diff --git a/headers/openvr_driver.h b/headers/openvr_driver.h
index 54d26d8..f664cd8 100644
--- a/headers/openvr_driver.h
+++ b/headers/openvr_driver.h
@@ -15,8 +15,8 @@
namespace vr
{
static const uint32_t k_nSteamVRVersionMajor = 1;
- static const uint32_t k_nSteamVRVersionMinor = 6;
- static const uint32_t k_nSteamVRVersionBuild = 10;
+ static const uint32_t k_nSteamVRVersionMinor = 7;
+ static const uint32_t k_nSteamVRVersionBuild = 15;
} // namespace vr
// vrtypes.h
@@ -432,6 +432,7 @@ enum ETrackedDeviceProperty
Prop_ExpectedControllerType_String = 2074,
Prop_HmdTrackingStyle_Int32 = 2075, // one of EHmdTrackingStyle
Prop_DriverProvidedChaperoneVisibility_Bool = 2076,
+ Prop_HmdProvidesDisplaySettings_Bool = 2077,
Prop_DisplayAvailableFrameRates_Float_Array = 2080, // populated by compositor from actual EDID list when available from GPU driver
@@ -483,11 +484,13 @@ enum ETrackedDeviceProperty
Prop_NamedIconPathDeviceNotReady_String = 5006, // {driver}/icons/icon_filename - PNG for static icon, or GIF for animation, 50x32 for headsets and 32x32 for others
Prop_NamedIconPathDeviceStandby_String = 5007, // {driver}/icons/icon_filename - PNG for static icon, or GIF for animation, 50x32 for headsets and 32x32 for others
Prop_NamedIconPathDeviceAlertLow_String = 5008, // {driver}/icons/icon_filename - PNG for static icon, or GIF for animation, 50x32 for headsets and 32x32 for others
+ Prop_NamedIconPathDeviceStandbyAlert_String = 5009, // {driver}/icons/icon_filename - PNG for static icon, or GIF for animation, 50x32 for headsets and 32x32 for others
// Properties that are used by helpers, but are opaque to applications
Prop_DisplayHiddenArea_Binary_Start = 5100,
Prop_DisplayHiddenArea_Binary_End = 5150,
Prop_ParentContainer = 5151,
+ Prop_OverrideContainer_Uint64 = 5152,
// Properties that are unique to drivers
Prop_UserConfigPath_String = 6000,
@@ -807,8 +810,8 @@ enum EVREventType
VREvent_ProcessConnected = 1306,
VREvent_ProcessDisconnected = 1307,
- VREvent_Compositor_MirrorWindowShown = 1400,
- VREvent_Compositor_MirrorWindowHidden = 1401,
+ //VREvent_Compositor_MirrorWindowShown = 1400, // DEPRECATED
+ //VREvent_Compositor_MirrorWindowHidden = 1401, // DEPRECATED
VREvent_Compositor_ChaperoneBoundsShown = 1410,
VREvent_Compositor_ChaperoneBoundsHidden = 1411,
VREvent_Compositor_DisplayDisconnected = 1412,
@@ -847,6 +850,9 @@ enum EVREventType
VREvent_SystemReport_Started = 1900, // user or system initiated generation of a system report. broadcast
+ VREvent_Monitor_ShowHeadsetView = 2000, // data is process
+ VREvent_Monitor_HideHeadsetView = 2001, // data is process
+
// Vendors are free to expose private events in this reserved region
VREvent_VendorSpecific_Reserved_Start = 10000,
VREvent_VendorSpecific_Reserved_End = 19999,
@@ -1546,6 +1552,7 @@ enum EVRInitError
VRInitError_Driver_HmdDriverIdOutOfBounds = 211,
VRInitError_Driver_HmdDisplayMirrored = 212,
VRInitError_Driver_HmdDisplayNotFoundLaptop = 213,
+ // Never make error 259 because we return it from main and it would conflict with STILL_ACTIVE
VRInitError_IPC_ServerInitFailed = 300,
VRInitError_IPC_ConnectFailed = 301,
@@ -1747,7 +1754,7 @@ struct CameraVideoStreamFrameHeader_t
uint32_t nFrameSequence;
- TrackedDevicePose_t standingTrackedDevicePose;
+ TrackedDevicePose_t trackedDevicePose;
uint64_t ulFrameExposureTime; // mid-point of the exposure of the image in host system ticks
};
@@ -1963,6 +1970,7 @@ enum ECameraCompatibilityMode
CAMERA_COMPAT_MODE_ISO_40FPS,
CAMERA_COMPAT_MODE_ISO_35FPS,
CAMERA_COMPAT_MODE_ISO_30FPS,
+ CAMERA_COMPAT_MODE_ISO_15FPS,
MAX_CAMERA_COMPAT_MODES
};
@@ -2020,7 +2028,7 @@ VR_CAMERA_DECL_ALIGN( 8 ) struct CameraVideoStreamFrame_t
double m_flSyncMarkerError;
- TrackedDevicePose_t m_StandingTrackedDevicePose; // Supplied by HMD layer when used as a tracked camera
+ TrackedDevicePose_t m_RawTrackedDevicePose; // Raw-and-uncalibrated pose, supplied by HMD layer when used as a tracked camera
uint64_t m_pImageData;
};
@@ -2188,7 +2196,10 @@ namespace vr
static const char * const k_pch_SteamVR_MotionSmoothingOverride_Int32 = "motionSmoothingOverride";
static const char * const k_pch_SteamVR_ForceFadeOnBadTracking_Bool = "forceFadeOnBadTracking";
static const char * const k_pch_SteamVR_DefaultMirrorView_Int32 = "mirrorView";
- static const char * const k_pch_SteamVR_ShowMirrorView_Bool = "showMirrorView";
+ static const char * const k_pch_SteamVR_ShowLegacyMirrorView_Bool = "showLegacyMirrorView";
+ static const char * const k_pch_SteamVR_MirrorViewVisibility_Bool = "showMirrorView";
+ static const char * const k_pch_SteamVR_MirrorViewDisplayMode_Int32 = "mirrorViewDisplayMode";
+ static const char * const k_pch_SteamVR_MirrorViewEye_Int32 = "mirrorViewEye";
static const char * const k_pch_SteamVR_MirrorViewGeometry_String = "mirrorViewGeometry";
static const char * const k_pch_SteamVR_MirrorViewGeometryMaximized_String = "mirrorViewGeometryMaximized";
static const char * const k_pch_SteamVR_StartMonitorFromAppLaunch = "startMonitorFromAppLaunch";
@@ -2217,6 +2228,9 @@ namespace vr
static const char * const k_pch_SteamVR_HmdDisplayColorGainR_Float = "hmdDisplayColorGainR";
static const char * const k_pch_SteamVR_HmdDisplayColorGainG_Float = "hmdDisplayColorGainG";
static const char * const k_pch_SteamVR_HmdDisplayColorGainB_Float = "hmdDisplayColorGainB";
+ static const char * const k_pch_SteamVR_CustomIconStyle_String = "customIconStyle";
+ static const char * const k_pch_SteamVR_CustomOffIconStyle_String = "customOffIconStyle";
+ static const char * const k_pch_SteamVR_CustomIconForceUpdate_String = "customIconForceUpdate";
//-----------------------------------------------------------------------------
// direct mode keys
@@ -2346,6 +2360,7 @@ namespace vr
static const char * const k_pch_Dashboard_UseWebSettings = "useWebSettings";
static const char * const k_pch_Dashboard_UseWebIPD = "useWebIPD";
static const char * const k_pch_Dashboard_UseWebPowerMenu = "useWebPowerMenu";
+ static const char * const k_pch_Dashboard_UseWebNotifications = "useWebNotifications";
//-----------------------------------------------------------------------------
// model skin keys
@@ -2799,6 +2814,11 @@ static const char *IVRCompositorPluginProvider_Version = "IVRCompositorPluginPro
namespace vr
{
+ /** This container is automatically created before a display redirect device is activated.
+ * Any properties in this container will be returned when that property is read from the HMD's
+ * property container. */
+ static const PropertyContainerHandle_t k_ulDisplayRedirectContainer = 0x600000003;
+
enum EPropertyWriteType
{
PropertyWrite_Set = 0,